summaryrefslogtreecommitdiff
path: root/include/tinyff/tinyff.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/tinyff/tinyff.h')
-rw-r--r--include/tinyff/tinyff.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/include/tinyff/tinyff.h b/include/tinyff/tinyff.h
index 48c4bbf..51298ef 100644
--- a/include/tinyff/tinyff.h
+++ b/include/tinyff/tinyff.h
@@ -1 +1,12 @@
-// TODO: Include all formats \ No newline at end of file
+// TODO: Include all formats
+
+
+
+#include "common.h"
+#include "stream.h"
+typedef struct {
+ // Debug settings
+ ff_stream* ff_debug_stream;
+ ff_flag ff_debug_enabled;
+
+} ff_ctx; \ No newline at end of file